@@ -433,7 +433,7 @@ sub do_build {
     } else {
         my $key = $self->get_upstream_signing_key($dir);
         if (-e $key) {
-            error(g_('upstream signing key but no upstream tarball signature'));
+            warning(g_('upstream signing key but no upstream tarball signature'));
         }
     }
 
